import React from "react";
import { Button } from "@fchh/fcos-suite-ui";
import { SENDINBLUE_ENDPOINTS } from "@config/index";

interface Props {
  locale: "de" | "en";
  title?: string;
  placeholder: string;
  buttonText: string;
  backgroundColor?: string;
  className?: string;
  light?: boolean;
  size?: "xs" | "sm" | "md" | "lg" | "xl";
  privacyText?: React.ReactNode;
  id?: string;
}
const NewsletterForm: React.FC<Props> = ({
  locale,
  title,
  placeholder,
  buttonText,
  className,
  light,
  privacyText,
  size = "md",
  id
}) => {
  return (
    <div
      className={`fc-w-full fc-order-1 md:fc-order-2 fc-my-0 ${
        className || ""
      }`}
      id={id}
    >
      {title && (
        <h5
          className={`font-karla fc-text-base ${
            light ? "fc-text-pearl-200" : "fc-text-grey-900"
          } fc-leading-6 fc-font-semibold fc-tracking-wide fc-uppercase`}
        >
          {title}
        </h5>
      )}
      <form
        className="fc-flex fc-w-full md:fc-flex-row fc-flex-col fc-gap-3 sm:fc-gap-3.5 fc-mt-3"
        id="sib-form"
        method="POST"
        action={SENDINBLUE_ENDPOINTS[locale]}
        data-type="subscription"
      >
        <input
          id="EMAIL"
          name="EMAIL"
          autoComplete="off"
          className="fc-w-full fc-grow fc-bg-white fc-rounded fc-outline-0 fc-px-3 fc-py-2 font-plex fc-text-grey-500 fc-text-base fc-leading-6 fc-font-normal"
          type="email"
          placeholder={placeholder}
          data-required="true"
          required
        />
        <Button
          text={buttonText}
          type={light ? "tertiary" : "primary"}
          buttonType="submit"
          size={size}
        />
        <input type="hidden" name="locale" value={locale} />
      </form>
      {privacyText && (
        <div
          className={`${
            light ? "fc-text-white" : "fc-text-black"
          } fc-text-sm fc-mt-2`}
        >
          {privacyText}
        </div>
      )}
    </div>
  );
};

export default NewsletterForm;
