/**
 * Return the base URL of the current page with or without trailing slash depending on the given parameter.#
 * This value is read from the Astro config file (it doesn't need to be set in .env file).
 */
export const getBaseUrl = (withoutEndingSlash?: boolean): string => {
  const baseUrl = import.meta.env.BASE_URL || "/";

  if (withoutEndingSlash) {
    return baseUrl.endsWith("/") ? baseUrl.slice(0, -1) : baseUrl;
  }
  return baseUrl;
};

/**
 * Prefix a given path with a base url, if the given path is NOT a valid external URL.
 * @param path
 * @param baseUrl
 * @returns
 */

export const prefixWithBaseIfNotUrl = (
  path: string,
  baseUrl?: string
): string => {
  if (baseUrl) {
    const isExternalUrl = path.toLowerCase().startsWith("http");
    const hasTrailingSlash = path.endsWith("/");

    return isExternalUrl
      ? path
      : `${baseUrl}${hasTrailingSlash ? "" : "/"}${path}`;
  }
  return path;
};
